.. _data_container:

.. index::
   single: Monte Carlo; Data container

Data containers
===============


.. index::
   single: Class reference; DataContainer
   single: Monte Carlo; data container

DataContainer
-------------

.. autoclass:: mchammer.DataContainer
   :members:
   :inherited-members:


.. index::
   single: Class reference; WangLandauDataContainer
   single: Monte Carlo; Wang-Landau data container

WangLandauDataContainer
-----------------------

.. autoclass:: mchammer.WangLandauDataContainer
   :members:
   :inherited-members:


.. _data_container_analysis_functions:

Analysis functions
------------------

.. autofunction:: mchammer.data_containers.get_average_observables_wl

.. autofunction:: mchammer.data_containers.get_average_cluster_vectors_wl

.. autofunction:: mchammer.data_containers.get_density_of_states_wl

.. automodule:: mchammer.data_analysis
   :members:
